@@ -9,6 +9,7 @@ import datetime
 from requests.exceptions import HTTPError
 import onepasswordconnectsdk
 from onepasswordconnectsdk.models import Item, ItemVault
+from onepasswordconnectsdk.models.constants import CONNECT_HOST_ENV_VARIABLE
 
 
 ENV_SERVICE_ACCOUNT_JWT_VARIABLE = "OP_CONNECT_TOKEN"
@@ -481,7 +482,7 @@ def new_client(url: str, token: str):
     return Client(url=url, token=token)
 
 
-def new_client_from_environment(url: str):
+def new_client_from_environment(url: str = None):
     """Builds a new client for interacting with 1Password Connect
     using the OP_TOKEN environment variable
 
@@ -494,6 +495,13 @@ def new_client_from_environment(url: str):
     """
     token = os.environ.get(ENV_SERVICE_ACCOUNT_JWT_VARIABLE)
 
+    if url is None:
+        url = os.environ.get(CONNECT_HOST_ENV_VARIABLE)
+        if url is None:
+            raise EnvironmentHostNotSetException(
+                f"{CONNECT_HOST_ENV_VARIABLE} environment variable is not set"
+            )
+
     if token is None:
         raise EnvironmentTokenNotSetException(
             "There is no token available in the "
@@ -510,6 +518,8 @@ class OnePasswordConnectSDKError(RuntimeError):
 class EnvironmentTokenNotSetException(OnePasswordConnectSDKError, TypeError):
     pass
 
+class EnvironmentHostNotSetException(OnePasswordConnectSDKError, TypeError):
+    pass
 
 class FailedToRetrieveItemException(OnePasswordConnectSDKError):
     pass
